<?php
/***
*
*@package binzcms
*@version $id:FrontIndexClass.php, v 1.0
*@author 斌子
*@Sat Jan 03 23:24:53 CST 2009
*@copyright (c) 2009-2010 binzcms
*
*/
if(!defined("BINZCMS")) {
	die("hacking");
}
/**
 *
 * FrontIndexClass
 * 首页控制类
 * 
 */
include(MOD_PATH."/ModFrontIndexClass.php");
class FrontIndexClass extends ModFrontIndexClass {
	/**
	 * __construct
	 *
	 * 构造函数
	 * @access  public（权限）
	 */
	public function __construct($act) {
		/*获取方法*/
		if(empty($act)) {
			$act	= "index_show";
		}

		/*合法action*/
		$this->allow_action	= array(
		'index_show'				//首页显示
		);
		
		parent::__construct($act);

		/*非法action，$act从新赋值*/
		if(!$this->action_state) {
			$act	= "index_show";
		}
		/*载入语言包*/
		$this->import_language('FrontIndex,FrontCommon');
		
		$this->$act();
	}
	/**
	 * index_show
	 *
	 * 首页显示
	 * @access  public（权限）
	 * 
	 * 
	 */
	private function index_show() {
		$commend_art	= array();	//推荐文章
		$friend_link	= array();	//友情链接
		$vote_array		= array();	//投票
		$top_menu		= array();	//顶部菜单
		$class_list		= array();	//分类列表

		/*推荐资讯（整站推荐）*/
		$commend_art	= $this->mod_front_commend_article();
		$this->binz_tpl->set_var('commend_art',$commend_art);

		/*最新资讯*/
		$new_art		= $this->mod_front_new_article();
		$this->binz_tpl->set_var('new_art',$new_art);

		/*焦点新闻*/
		$hot_art		= $this->mod_front_hot_article();
		$this->binz_tpl->set_var('hot_art',$hot_art);

		/*分类列表*/
		$class_list		= $this->mod_front_class_list();
		$this->binz_tpl->set_var('class_list',$class_list);
		
		/*网站公告*/
		$notice_list	= $this->mod_front_notice_list(5);
		$this->binz_tpl->set_var('notice_list',$notice_list);
		
		/*投票*/
		$vote_array		= $this->mod_front_index_vote();
		$this->binz_tpl->set_var('vote_array',$vote_array);

		/*友情链接*/
		$friend_link	= $this->mod_front_index_flink();
		$this->binz_tpl->set_var('friend_link',$friend_link);

		$this->binz_tpl->set_var('show_menu','index');
		$this->binz_tpl->set_tag('index');
	}
	/**
	 * __destruct
	 *
	 * 析构函数
	 * @access  public（权限）
	 */
	public function __destruct() {

	}
}
?>